4.14. umbra.components.factory.preferencesManager.preferencesManager — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »

# 4.14. umbra.components.factory.preferencesManager.preferencesManager

preferencesManager.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `PreferencesManager` Component Interface class.

Others:

## 4.14.1. Module Attributes

`umbra.components.factory.preferencesManager.preferencesManager.` `LOGGER`

`umbra.components.factory.preferencesManager.preferencesManager.` `COMPONENT_UI_FILE`

## 4.14.2. Classes

class `umbra.components.factory.preferencesManager.preferencesManager.` `PreferencesManager`(parent=None, name=None, *args, **kwargs)

  Bases: `manager.qwidgetComponent.QWidgetComponent`

  This class is the `umbra.components.factory.preferencesManager.preferencesManager` Component Interface class.
  It exposes Application preferences inside a dedicated QDockWidget window.

  Parameters: | parent – Object parent. ( QObject ) name – Component name. ( String ) *args – Arguments. ( * ) **kwargs – Keywords arguments. ( ** )

  `dockArea`

    This method is the property for self.__dockArea attribute.

    Returns: | self.__dockArea. ( Integer )

  `engine`

    This method is the property for self.__engine attribute.

    Returns: | self.__engine. ( QObject )

  `settings`

    This method is the property for self.__settings attribute.

    Returns: | self.__settings. ( QSettings )

  `activate`(engine)

    This method activates the Component.

    Parameters: | engine – Engine to attach the Component to. ( QObject )
    Returns: | Method success. ( Boolean )

  `deactivate`()

    This method deactivates the Component.

  `initializeUi`()

    This method initializes the Component ui.

    Returns: | Method success. ( Boolean )

  `uninitializeUi`()

    This method uninitializes the Component ui.

  `addWidget`()

    This method adds the Component Widget to the engine.

    Returns: | Method success. ( Boolean )

  `removeWidget`()

    This method removes the Component Widget from the engine.

  `setLoggingFormatter`()

    This method sets the logging formatter.

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »